@@ -28,11 +28,13 @@ only be called via that package.
 
 =head1 DESCRIPTION
 
-The main purpose of the Win32::Process::Info package is to get whatever
+The main purpose of the Win32::Process::Info::NT package is to get whatever
 information is convenient (for the author!) about one or more Windows
 32 processes. GetProcInfo (which see) is therefore the most-important
 subroutine in the package. See it for more information.
 
+This package returns Windows process IDs, even under Cygwin.
+
 Unless explicitly stated otherwise, modules, variables, and so
 on are considered private. That is, the author reserves the right
 to make arbitrary changes in the way they work, without telling
@@ -75,9 +77,7 @@ return undef;	## no critic (ProhibitExplicitReturnUndef)
 
 use base qw{ Win32::Process::Info };
 
-use Win32::Process::Info qw{ $MY_PID };
-
-our $VERSION = '1.019_02';
+our $VERSION = '1.019_03';
 
 our $AdjustTokenPrivileges;
 our $CloseHandle;
@@ -345,13 +345,14 @@ my $tac = TOKEN_READ;
 my @pinf;
 
 my $dat;
+my $my_pid = $self->My_Pid();
 my %sid_to_name;
 my @trydac = (
     PROCESS_QUERY_INFORMATION | PROCESS_VM_READ,
     PROCESS_QUERY_INFORMATION,
     );
 
-foreach my $pid (map {$_ eq '.' ? $MY_PID : $_} @args) {
+foreach my $pid (map {$_ eq '.' ? $my_pid : $_} @args) {
 
     local $^E = 0;
     $dat = $self->_build_hash (undef, ProcessId => $pid);
@@ -529,8 +530,9 @@ reference to the list is returned.
 sub ListPids {
 my ( $self, @args ) = @_;
 my $filter = undef;
+my $my_pid = $self->My_Pid();
 @args and $filter = {
-    map { ($_ eq '.' ? $MY_PID : $_) => 1 } @args
+    map { ($_ eq '.' ? $my_pid : $_) => 1 } @args
 };
 $EnumProcesses ||= _map ('PSAPI', 'EnumProcesses', [qw{P N P}], 'I');
 my $psiz = 4;
